var React = require('react');
var ReactDOM = require('react-dom');
var TightForm = require('../../dist/react-tight-form');

var App = React.createClass({

  render: function() {
    return (
      <div>
        <h1>ReactTightForm</h1>
        <hr/>
        <div className="callout callout-danger">
          <h4><code>ReactTightForm</code> is not responsive (yet)</h4>
          <p>This current version does not support responsiveness... yet. In a future version I plan to address this as I will have to figure out how to best display content in smaller viewports.</p>
        </div>
        <div className="callout callout-info">
          <h4>May require custom widths</h4>
          <p>Inputs and selects have <code>width: auto;</code> applied by default. Depending on your layout, additional custom widths may be required.</p>
        </div>
        <div className="callout callout-warning">
          <h4>Limited input type support in <code>v0.1.0</code></h4>
          <p>Currently <code>ReactTightForm</code> only supports single <code>{'<select>'}</code> elements, textual <code>{'<input>'}</code> elements, checkbox and radio <code>{'<input>'}</code> elements.</p>
        </div>
        <div className="callout callout-danger">
          <h4>Unique <code>id</code> property required for <code>checkbox</code> and <code>radio</code> input types</h4>
          <p><code>ReactTightForm</code> uses image sprites to generate the checkbox and radio buttons. Because of this, we use a CSS trick involving <code>label</code> elements and there needs to be a unique <code>id</code> attribute attached in order to detect changes.</p>
        </div>
        <h2>Basic example</h2>
        <p>Below is a basic example of what <code>ReactTightForm</code> can do.</p>
        <div className="example">
          <TightForm>
            <TightForm.Input
              id="exampleName"
              label="Name"
              labelProps={{style: {width: 90}}}
              placeholder="Jane Doe"
              name="name"
              type="text"
            />
            <TightForm.Input
              id="exampleEmail"
              label="Email"
              labelProps={{style: {width: 75}}}
              placeholder="jane.doe@example.com"
              name="email"
              type="email"
            />
            <TightForm.Input
              id="exampleRememberMe"
              label="Remember me"
              name="rememberMe"
              type="checkbox"
            />
          </TightForm>
          <TightForm>
            <TightForm.Input
              id="examplePassword"
              label="Password"
              labelProps={{style: {width: 90}}}
              name="password"
              type="password"
            />
            <TightForm.Input
              id="exampleGender"
              label="Gender"
              labelProps={{style: {width: 75}}}
              name="gender"
              type="select"
            >
              <option>Female</option>
              <option>Male</option>
            </TightForm.Input>
          </TightForm>
          <TightForm isLast>
            <TightForm.Label style={{width: 90}}>
              Theme
            </TightForm.Label>
            <TightForm.Input
              id="themeDark"
              label="Dark"
              name="theme"
              noRightBorder={true}
              type="radio"
              value="dark"
            />
            <TightForm.Input
              id="themeLight"
              label="Light"
              name="theme"
              type="radio"
              value="light"
            />
          </TightForm>
        </div>
        <div className="highlight">
          <pre>
            <code>
              {'<div>'}<br/>
              {'  <TightForm>'}<br/>
              {'    <TightForm.Input'}<br/>
              {'      id="exampleName"'}<br/>
              {'      label="Name"'}<br/>
              {'      labelProps={{style: {width: 90}}}'}<br/>
              {'      placeholder="Jane Doe"'}<br/>
              {'      name="name"'}<br/>
              {'      type="text"'}<br/>
              {'    />'}<br/>
              {'    <TightForm.Input'}<br/>
              {'      id="exampleEmail"'}<br/>
              {'      label="Email"'}<br/>
              {'      labelProps={{style: {width: 75}}}'}<br/>
              {'      placeholder="jane.doe@example.com"'}<br/>
              {'      name="email"'}<br/>
              {'      type="email"'}<br/>
              {'    />'}<br/>
              {'    <TightForm.Input'}<br/>
              {'      id="exampleRememberMe"'}<br/>
              {'      label="Remember me"'}<br/>
              {'      name="rememberMe"'}<br/>
              {'      type="checkbox"'}<br/>
              {'    />'}<br/>
              {'  </TightForm>'}<br/>
              {'  <TightForm'}<br/>
              {'    <TightForm.Input'}<br/>
              {'      id="examplePassword"'}<br/>
              {'      label="Password"'}<br/>
              {'      labelProps={{style: {width: 90}}}'}<br/>
              {'      name="password"'}<br/>
              {'      type="password"'}<br/>
              {'    />'}<br/>
              {'    <TightForm.Input'}<br/>
              {'      id="exampleGender"'}<br/>
              {'      label="Gender"'}<br/>
              {'      labelProps={{style: {width: 75}}}'}<br/>
              {'      name="gender"'}<br/>
              {'      type="select"'}<br/>
              {'    >'}<br/>
              {'      <option>Female</option>'}<br/>
              {'      <option>Male</option>'}<br/>
              {'    </TightForm.Input>'}<br/>
              {'  </TightForm>'}<br/>
              {'  <TightForm isLast={true}>'}<br/>
              {'    <TightForm.Label style={{width: 90}}>Theme</TightForm.Label>'}<br/>
              {'    <TightForm.Input'}<br/>
              {'      id="themeDark"'}<br/>
              {'      label="Dark"'}<br/>
              {'      name="theme"'}<br/>
              {'      noRightBorder={true}'}<br/>
              {'      type="radio"'}<br/>
              {'      value="dark"'}<br/>
              {'    />'}<br/>
              {'    <TightForm.Input'}<br/>
              {'      id="themeLight"'}<br/>
              {'      label="Light"'}<br/>
              {'      name="theme"'}<br/>
              {'      noRightBorder={true}'}<br/>
              {'      type="radio"'}<br/>
              {'      value="light"'}<br/>
              {'    />'}<br/>
              {'  </TightForm>'}<br/>
              {'</div>'}
            </code>
          </pre>
        </div>
        <h2>Complete example</h2>
        <p>If you noticed from our previous example, the <code>{'<TightForm.Input>'}</code> component actually renders a "group".</p>
        <p>
          A "group" consists of a <code>{'<TightForm.Group>'}</code> element wrapping a
          <code>{'<TightForm.Label>'}</code> and an <code>{'<input>'}</code> or <code>{'<select>'}</code> element.
        </p>
        <p>Below a simple example without using <code>{'<TightForm.Input>'}</code> component to generate our groups.</p>
        <div className="example">
          <TightForm isLast>
            <TightForm.Group>
              <TightForm.Label htmlFor="name" style={{width: 90}}>
                Name
              </TightForm.Label>
              <TightForm.Input
                name="name"
                placeholder="Jane Doe"
                standalone={true}
                type="text"
              />
            </TightForm.Group>
          </TightForm>
        </div>
        <div className="highlight">
          <pre>
            <code>
              {'<TightForm isLast={true}>'}<br/>
              {'  <TightForm.Group>'}<br/>
              {'    <TightForm.Label htmlFor="name" style={{width: 90}}>'}<br/>
              {'      Name'}<br/>
              {'    </TightForm.Label>'}<br/>
              {'    <TightForm.Input'}<br/>
              {'      name="name"'}<br/>
              {'      placeholder="Jane Doe"'}<br/>
              {'      standalone={true}'}<br/>
              {'      type="text"'}<br/>
              {'    />'}<br/>
              {'  </TightForm.Group>'}<br/>
              {'</TightForm>'}
            </code>
          </pre>
        </div>
        <h2>Standalone input or select</h2>
        <p>If you just want to render a <code>ReactTightForm</code> styled input, set the <code>standalone</code> property to <code>true</code></p>
        <div className="example">
          <TightForm.Input
            name="name"
            placeholder="Jane Doe"
            standalone={true}
            style={{borderWidth: 1, minWidth: 250}}
            type="text"
          />
        </div>
        <div className="highlight">
          <pre>
            <code>
              {'<TightForm.Input'}<br/>
              {'  name="name"'}<br/>
              {'  placeholder="Jane Doe"'}<br/>
              {'  standalone={true}'}<br/>
              {'  style={{borderWidth: 1, minWidth: 250}}'}<br/>
              {'  type="text"'}<br/>
              {'/>'}
            </code>
          </pre>
        </div>
        <h2>Props</h2>
        <table className="table table-condensed table-striped">
          <thead>
            <tr>
              <th>Name</th>
              <th>Type</th>
              <th>Default</th>
              <th>Description</th>
            </tr>
          </thead>
          <tbody>
            <tr>
              <td colSpan="4">
                <em>Coming soon</em>
              </td>
            </tr>
          </tbody>
        </table>
        <h2><code>{'TightForm.Input'}</code> public methods</h2>
        <table className="table table-condensed table-striped">
          <thead>
            <tr>
              <th>Name</th>
              <th>Arguments</th>
              <th>Description</th>
            </tr>
          </thead>
          <tbody>
            <tr>
              <td colSpan="3">
                <em>Coming soon</em>
              </td>
            </tr>
          </tbody>
        </table>
      </div>
    );
  }

});

ReactDOM.render(<App />, document.getElementById('app'));